@@ -1,3 +1,4 @@
+from commonutils import StaticUtils
 from tkinter import IntVar
 from .labeledcontainer import LabeledContainer
 
@@ -6,6 +7,10 @@ class LabeledRadioButtonGroup(LabeledContainer):
       kw["value"] = IntVar()
       
       super().__init__(master, **kw)
+      
+      kw["value"].set(StaticUtils.getOrSetIfAbsent(self._valueBuffer, 0, 0))
+      
+      kw["value"].trace_add("write", lambda *_: StaticUtils.setSafely(self._valueBuffer, 0, self.value.get()))
    
    def _inflateChildren(self):
       for child in self._baseContainerChildren:
